# stmpy

Stmpy is a python-based data analysis package for stmpy images.

  - Load default Nanonis filetypes
  - Analysis tools: curve fitting, linecuts, drift correction and more.
  - Easily create movies and high-quality figures

Get started with the stmpy101 tutorial in `stmpy/doc/`

### Installation

For developers

1. **Clone** or **download** `stmpy` to your local drive.
2. Navigate to within local copy of stmpy.
```sh
$ python setup.py develop
```

For users

```sh
$ pip install stmpy-python
```



License
----

MIT
